@@ -219,6 +219,9 @@ struct media_session {
     int skip_write_frames;
     int hw_coding;
     int hw_dtmf;
+#ifdef LIBSANGOMA_VERSION
+    int has_hwec;
+#endif
     int udp_sync_cnt;
     
 #ifdef WP_HPTDM_API
